[Python-checkins] cpython (3.2): Issue #12250: test_socketserver uses a timeout of 60 seconds instead of 20

victor.stinner python-checkins at python.org
Thu Jul 14 15:41:10 CEST 2011


http://hg.python.org/cpython/rev/05dfed82457a
changeset:   71327:05dfed82457a
branch:      3.2
parent:      71324:530ba6c7e578
user:        Victor Stinner <victor.stinner at haypocalc.com>
date:        Thu Jul 14 14:53:24 2011 +0200
summary:
  Issue #12250: test_socketserver uses a timeout of 60 seconds instead of 20

test_shutdown() may fail on very slow buildbots like FreeBSD 6.4 just because
of the arbitrary timeout.

files:
  Lib/test/test_socketserver.py |  3 +--
  1 files changed, 1 insertions(+), 2 deletions(-)


diff --git a/Lib/test/test_socketserver.py b/Lib/test/test_socketserver.py
--- a/Lib/test/test_socketserver.py
+++ b/Lib/test/test_socketserver.py
@@ -66,7 +66,7 @@
     """Test all socket servers."""
 
     def setUp(self):
-        signal_alarm(20)  # Kill deadlocks after 20 seconds.
+        signal_alarm(60)  # Kill deadlocks after 60 seconds.
         self.port_seed = 0
         self.test_files = []
 
@@ -283,4 +283,3 @@
 
 if __name__ == "__main__":
     test_main()
-    signal_alarm(3)  # Shutdown shouldn't take more than 3 seconds.

-- 
Repository URL: http://hg.python.org/cpython


More information about the Python-checkins mailing list